protocol_system_call

Function protocol_system_call 

pub fn protocol_system_call<T>(
    tx: &T,
) -> Result<Option<ProtocolSystemCall>, Report>
where T: Transaction,
Available on crate feature monad only.
Converts a canonical Monad envelope into its dedicated system call.

Returns an error when the transaction uses Monad’s reserved protocol sender but does not satisfy the canonical envelope rules.